@@ -1,9 +1,12 @@
-static char RcsId[] = "$Header: /segfs/dbase/res/svc/ndbm/RCS/main_svc.cpp,v 6.11 2001/05/15 14:56:55 goetz Exp $";
+static char RcsId[] = "$Header: main_svc.cpp,v 6.12 2002/03/12 11:25:49 goetz Exp $";
+
+/* $Log:	main_svc.cpp,v $
+Revision 6.12  2002/03/12  11:25:49  11:25:49  goetz (Andy Goetz)
+removed prototypes for get_myaddress() and gethostname()
+
+Revision 6.11  2001/05/15  14:56:55  14:56:55  goetz (Andy Goetz)
+included prototype for gethostname (needed by solaris platforms)
 
-/* $Log: main_svc.cpp,v $
- * Revision 6.11  2001/05/15 14:56:55  goetz
- * included prototype for gethostname (needed by solaris platforms)
- *
  * Revision 6.10  2001/01/08 11:45:53  goetz
  * added patch by B.Pedersen to support querying events
  *
@@ -108,8 +111,6 @@ extern int errno;
 extern "C" 
 {
   u_long gettransient(const char *);
-  void get_myaddress(struct sockaddr_in *);
-  int gethostname(char *,size_t);
 }
 
 typedef char * (* DbRpcLocalFunc)(...);
