@@ -13,15 +13,69 @@
  Original:	January 1991
 
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:59 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:52 $
 
  $Author: goetz $
 
- $Log:	API.h,v $
- * Revision 8.30  2001/11/12  09:59:59  09:59:59  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ $Log: API.h,v $
+ Revision 8.48  2002/09/04 12:55:52  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:56:59  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:29  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:02  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:32  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:38  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:43  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:07:00  goetz
+ ported -nodb option to Windows
+
+ * Revision 8.40  2002/03/18  10:10:47  10:10:47  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:51  05:48:51  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:25  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:20  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:45  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:43  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:07  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:48  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:44:55  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:06  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:59  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:08  goetz
  fixed error in CORBA::is_nil() test
 
@@ -213,7 +267,7 @@
  */
 #ifdef _IDENT
 static char APIh[] =
-"@(#)$Header: API.h,v 8.30 2001/11/12 09:59:59 goetz Rel $";
+"@(#)$Header: /segfs/dserver/system/api/apilib/include/RCS/API.h,v 8.48 2002/09/04 12:55:52 goetz Rel $";
 #endif /* _IDENT */
 
 /*
@@ -336,6 +390,7 @@ typedef struct _devserver {
 	CLIENT      *asynch_clnt;
 	struct timeval asynch_timeout;
 	long        pending;
+	int         no_database;
 	} *devserver;
 
 
@@ -561,5 +616,12 @@ extern _DLLFunc void  dev_printdiag();
 
 extern char *dev_error_string;
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+void device_server (char *server_name, char *pers_name, int nodb, int pn, int n_device, char** device_list); 
+#ifdef __cplusplus
+}
+#endif
 #endif /* _api_h */
 
