@@ -13,12 +13,36 @@
  Original:	June 1992
 
 
- $Revision: 8.40 $
- $Date: 2002/03/18 10:10:48 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:52 $
 
  $Author: goetz $
 
- $Log:	ApiP.h,v $
+ $Log: ApiP.h,v $
+ Revision 8.48  2002/09/04 12:55:52  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:56:59  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:29  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:02  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:34  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:38  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:43  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:07:00  goetz
+ ported -nodb option to Windows
+
  * Revision 8.40  2002/03/18  10:10:48  10:10:48  goetz (Andy Goetz)
  * removed ^M from files which were confusing Ultra C++ compiler
  * 
@@ -244,7 +268,7 @@
  */
 #ifdef _IDENT
 static char ApiPh[] =
-"@(#)$Header: ApiP.h,v 8.40 2002/03/18 10:10:48 goetz Rel $";
+"@(#)$Header: /segfs/dserver/system/api/apilib/include/RCS/ApiP.h,v 8.48 2002/09/04 12:55:52 goetz Rel $";
 #endif /* _IDENT */
 
 
@@ -295,7 +319,11 @@ static char ApiPh[] =
  * defines to mark rpc connections
  */
 
+#ifndef _UCC
+#define NFILE 256 /* maximum number of server connections per process */
+#else
 #define NFILE 100 /* maximum number of server connections per process */
+#endif
 
 #define RPC_ERROR	1
 #define GOOD_SVC_CONN	0
@@ -738,5 +766,11 @@ void get_myaddress(struct sockaddr_in *);
 #endif /* __cplusplus */
 #endif /* solaris || _UCC */
 
+#ifdef __cplusplus
+extern "C" configuration_flags  config_flags;
+extern "C" nethost_info 	*multi_nethost;
+extern "C" dbserver_info        db_info;
+#endif
+
 #endif /* _apiP_h */
 
