@@ -1,5 +1,5 @@
 static char RcsId[]           = 
-"@(#)$Header: DevServerSig.c,v 8.30 2001/11/12 09:59:59 goetz Rel $";
+"@(#)$Header: /segfs/dserver/classes/main/src/RCS/DevServerSig.c,v 8.48 2002/09/04 12:55:53 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -16,14 +16,68 @@ static char RcsId[]           =
  Original:	June 1991
 
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:59 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:53 $
  $Author: goetz $
 
- $Log:	DevServerSig.c,v $
- * Revision 8.30  2001/11/12  09:59:59  09:59:59  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ $Log: DevServerSig.c,v $
+ Revision 8.48  2002/09/04 12:55:53  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:57:00  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:29  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:02  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:45  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:38  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:43  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:07:01  goetz
+ ported -nodb option to Windows
+
+ * Revision 8.40  2002/03/18  10:10:59  10:10:59  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:51  05:48:51  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:25  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:20  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:45  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:43  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:08  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:48  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:45:07  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:06  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:59  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:09  goetz
  fixed error in CORBA::is_nil() test
 
@@ -277,7 +331,11 @@ static void 	(*sig_tab [NUSIG])() = {SIG_DFL};
  * global external containing all device server config info
  */
 
+#ifdef __cplusplus
+extern "C" configuration_flags config_flags;
+#else
 extern configuration_flags config_flags;
+#endif
 
 /*+**********************************************************************
  Function   :  	extern long ds__signal()
@@ -485,18 +543,20 @@ void unregister_server (void)
 
 
 /*
- * if this is a bona fida device server then
- *
- *  unregister server from database device table
+ * if this is a bona fida device server and it is using the database
+ * then unregister server from database device table
  */
 
 	if (config_flags.device_server == True)
 	{
-   		if ( db_svc_unreg (config_flags.server_name,
-			   	&error) < 0 )
-	   	{
-	   		dev_printerror_no (SEND,"db_svc_unreg failed",error);
-	   	}		
+		if (!config_flags.no_database)
+		{
+   			if ( db_svc_unreg (config_flags.server_name,
+			   		&error) < 0 )
+	   		{
+	   			dev_printerror_no (SEND,"db_svc_unreg failed",error);
+	   		}		
+		}
 
 	/*
 	 *  destroy open client handles to message and database servers
@@ -504,20 +564,19 @@ void unregister_server (void)
 	 	clnt_destroy (db_info.conf->clnt);
 	 	clnt_destroy (msg_info.conf->clnt);
 	 */
-
+	}
 	/*
 	 * unregister synchronous version (4) of server from portmapper
 	 */
-		pmap_unset (config_flags.prog_number, API_VERSION);
-	}
+	pmap_unset (config_flags.prog_number, API_VERSION);
 	/*
  	 * unregister the asynchronous version (5) of the server from portmapper
  	 */
-		pmap_unset (config_flags.prog_number, ASYNCH_API_VERSION);
+	pmap_unset (config_flags.prog_number, ASYNCH_API_VERSION);
 	/*
 	 *  finally unregister version (1) used by gettransient_ut()
 	 */
-		pmap_unset (config_flags.prog_number, DEVSERVER_VERS);
+	pmap_unset (config_flags.prog_number, DEVSERVER_VERS);
 	
 /*
  * returning here and calling exit() later from main_signal_handler() will
