@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: event_api.c,v 8.40 2002/03/18 10:10:44 goetz Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dserver/system/api/apilib/src/RCS/event_api.c,v 8.48 2002/09/04 12:55:52 goetz Rel $";
 /*+*******************************************************************
 
  File       :	event_api.c
@@ -33,12 +33,36 @@ static char RcsId[] = "@(#)$Header: event_api.c,v 8.40 2002/03/18 10:10:44 goetz
 
  Original   :	April 1999
 
- $Revision: 8.40 $
- $Date: 2002/03/18 10:10:44 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:52 $
 
  $Author: goetz $
 
- $Log:	event_api.c,v $
+ $Log: event_api.c,v $
+ Revision 8.48  2002/09/04 12:55:52  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:56:58  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:28  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:01  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:30  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:37  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:42  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:06:59  goetz
+ ported -nodb option to Windows
+
  * Revision 8.40  2002/03/18  10:10:44  10:10:44  goetz (Andy Goetz)
  * removed ^M from files which were confusing Ultra C++ compiler
  * 
@@ -252,9 +276,17 @@ static char RcsId[] = "@(#)$Header: event_api.c,v 8.40 2002/03/18 10:10:44 goetz
 #include <_os9_sockets.h>
 #endif /* _UCC */
 
+#ifdef __cplusplus
+extern "C" configuration_flags config_flags;
+#else
 extern configuration_flags config_flags;
+#endif
 
+#ifdef __cplusplus
+extern "C" nethost_info *multi_nethost;
+#else
 extern nethost_info *multi_nethost;
+#endif
 
 extern server_connections svr_conns[];
 
