@@ -1,5 +1,5 @@
 static char RcsId[] = 
-"@(#)$Header: gen_api.c,v 8.30 2001/11/12 09:59:58 goetz Rel $";
+"@(#)$Header: /segfs/dserver/system/api/apilib/src/RCS/gen_api.c,v 8.48 2002/09/04 12:55:52 goetz Rel $";
 /*+*******************************************************************
 
  File       :	gen_api.c
@@ -13,15 +13,69 @@ static char RcsId[] =
 
  Original   :	January 1991
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:58 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:52 $
 
  $Author: goetz $
 
- $Log:	gen_api.c,v $
- * Revision 8.30  2001/11/12  09:59:58  09:59:58  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ $Log: gen_api.c,v $
+ Revision 8.48  2002/09/04 12:55:52  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:56:58  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:28  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:01  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:22  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:37  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:42  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:06:59  goetz
+ ported -nodb option to Windows
+
+ * Revision 8.40  2002/03/18  10:10:36  10:10:36  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:50  05:48:50  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:24  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:18  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:44  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:42  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:07  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:47  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:44:44  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:05  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:58  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:07  goetz
  fixed error in CORBA::is_nil() test
 
@@ -165,6 +219,13 @@ char *dev_error_stack=NULL; /* global pointer to dynamic error stack */
  *          Globals	                *
  ****************************************/
 
+/* for Windows C++ these symbols must be seen by libdbapi
+ * therefore declare them as extern "C" - andy 24/4/02
+ */
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 /*
  *  Types for global state flags for the current
  *  server or client status and for Message Server and Database
@@ -217,12 +278,20 @@ static _message_buffer 	message_buffer [NUMBER_OF_MSG_TYPES];
 nethost_info 	*multi_nethost;
 long max_nethost = 0;
 
+#ifdef WIN32
+static long win32_rpc_inited;
+#endif /* WIN32 */
+
 /*
  *  Debug globals
  */
 
 long debug_flag = 0x0;
 
+#ifdef __cplusplus
+}
+#endif
+
 /*+**********************************************************************
  Function   :   extern long msg_import()
 
@@ -1432,6 +1501,14 @@ static long setup_config (long *error)
 	    "\nsetup_config() : entering routine\n");
 #endif /* EBUG */
 
+#ifdef WIN32
+	if (!win32_rpc_inited)
+	{
+		rpc_nt_init();
+		win32_rpc_inited = 1;
+	}
+#endif /* WIN32 */
+
 	*error = 0;
 	memset ((char *)&manager_data,0,sizeof(manager_data));
 
@@ -1673,6 +1750,14 @@ long setup_config_multi (char *nethost, long *error)
 	static char		nethost_env[80];
 #endif
 
+#ifdef WIN32
+	if (!win32_rpc_inited)
+	{
+		rpc_nt_init();
+		win32_rpc_inited = 1;
+	}
+#endif /* WIN32 */
+
 	*error = 0;
 	memset ((char *)&manager_data,0,sizeof(manager_data));
 
@@ -2159,3 +2244,27 @@ long dev_error_push (char *error_string)
 
 	return(DS_OK);
 }
+
+/*+**********************************************************************
+ Function   :	long dev_error_clear()
+
+ Description:   Clear the dynmaic error stack. This can be useful for servers
+ 		who want to remove error messages from the stack and return
+		their own error only.
+
+ Arg(s) In  :   none
+
+ Arg(s) Out :   none
+
+ Return(s)  :   DS_OK or DS_NOTOK or DS_WARNING
+***********************************************************************-*/
+long dev_error_clear ()
+{
+	if (dev_error_stack != NULL)
+	{
+		free(dev_error_stack);
+		dev_error_stack = NULL;
+	}
+
+	return(DS_OK);
+}
