@@ -1,5 +1,5 @@
 static char RcsId[] =
-"@(#)$Header: sec_api.c,v 8.30 2001/11/12 09:59:58 goetz Rel $";
+"@(#)$Header: /segfs/dserver/system/api/apilib/src/RCS/sec_api.c,v 8.48 2002/09/04 12:55:52 goetz Rel $";
 /*+*******************************************************************
 
  File       :   sec_api.c
@@ -12,15 +12,69 @@ static char RcsId[] =
 
  Original   :   December 1993
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:58 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:52 $
 
  $Author: goetz $
 
- $Log:	sec_api.c,v $
- * Revision 8.30  2001/11/12  09:59:58  09:59:58  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ $Log: sec_api.c,v $
+ Revision 8.48  2002/09/04 12:55:52  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:56:58  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:28  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:01  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:27  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:37  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:42  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:06:59  goetz
+ ported -nodb option to Windows
+
+ * Revision 8.40  2002/03/18  10:10:41  10:10:41  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:50  05:48:50  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:24  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:18  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:44  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:42  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:07  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:47  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:44:49  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:05  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:58  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:07  goetz
  fixed error in CORBA::is_nil() test
 
@@ -332,7 +386,12 @@ static SecOpenConn 	conn_list = {
  * global variable defined in gen_api.c which keeps track of multi-nethosts
  */
 
+#ifdef __cplusplus
+extern "C" nethost_info *multi_nethost;
+#else
 extern nethost_info *multi_nethost;
+#endif
+
 /*
  * the following array have to be declared once per nethost
  * for multi-nethost. A user will have different security access
@@ -2158,6 +2217,8 @@ long _DLLFunc sec_svc_import (DevServerDevices *device, long connection_id,
 			    (struct sockaddr *)&(device->si_peeraddr), &len);
 #elif defined (linux)
 			    (struct sockaddr *)&(device->si_peeraddr), (socklen_t*)&len);
+#elif defined (WIN32)
+			    (struct sockaddr *)&(device->si_peeraddr), &len);
 #else
 			    (void *)&(device->si_peeraddr), &len);
 #endif /* _UCC || solaris || linux */
@@ -2223,6 +2284,8 @@ long _DLLFunc sec_svc_import (DevServerDevices *device, long connection_id,
 			    (struct sockaddr *)&(device->si_peeraddr), &len);
 #elif defined (linux)
 			    (struct sockaddr *)&(device->si_peeraddr), (socklen_t*)&len);
+#elif defined (WIN32)
+			    (struct sockaddr *)&(device->si_peeraddr), &len);
 #else
 			    (void *)&(device->si_peeraddr), &len);
 #endif /* _UCC || solaris || linux */
@@ -2793,6 +2856,8 @@ static long sec_verify_tcp_conn (DevServerDevices *device)
 			    (struct sockaddr *)&peeraddr, &len) == DS_NOTOK ||
 #elif defined (linux)
 			    (struct sockaddr *)&peeraddr, (socklen_t*)&len) == DS_NOTOK ||
+#elif defined (WIN32)
+			    (struct sockaddr *)&peeraddr, &len) == DS_NOTOK ||
 #else
 			    (void *)&peeraddr, &len) == DS_NOTOK ||
 #endif /* _UCC || solaris || linux */
