@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: tango_api.cpp,v 8.40 2002/03/18 10:10:45 goetz Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dserver/system/api/apilib/src/RCS/tango_api.cpp,v 8.48 2002/09/04 12:55:52 goetz Rel $";
 /*+*******************************************************************
 
  File       :	tango_api.c
@@ -17,12 +17,36 @@ static char RcsId[] = "@(#)$Header: tango_api.cpp,v 8.40 2002/03/18 10:10:45 goe
 
  Original   :	December 1999
 
- $Revision: 8.40 $
- $Date: 2002/03/18 10:10:45 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:52 $
 
  $Author: goetz $
 
- $Log:	tango_api.cpp,v $
+ $Log: tango_api.cpp,v $
+ Revision 8.48  2002/09/04 12:55:52  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:56:58  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:28  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:01  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:31  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:37  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:42  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:06:59  goetz
+ ported -nodb option to Windows
+
 // Revision 8.40  2002/03/18  10:10:45  10:10:45  goetz (Andy Goetz)
 // removed ^M from files which were confusing Ultra C++ compiler
 // 
@@ -213,6 +237,7 @@ long tango_db_import(char *db_name, char *db_host, long db_port, long *error)
 //
                 int _argc;
                 char **_argv;
+		string db_host_str(db_host);
  
 // Pass dummy arguments to init() because we don't have access to
 // argc and argv
@@ -222,7 +247,7 @@ long tango_db_import(char *db_name, char *db_host, long db_port, long *error)
  
                 orb = CORBA::ORB_init(_argc, _argv);                            
 	
-		tango_dbase = new Tango::Database(db_host, db_port, orb);
+		tango_dbase = new Tango::Database(db_host_str, db_port, orb);
 	}
 	catch (CORBA::Exception  &corba_exception) {
 #ifdef DEBUG
@@ -259,6 +284,7 @@ long tango_dev_import(char *dev_name, long access, devserver *ds_ptr, long *erro
 {
 	_tango_device tango_device_tmp;
 	long tango_device_free;
+	long i;
 
 	if (!tango_dbase_init) 
 	{
@@ -309,8 +335,9 @@ long tango_dev_import(char *dev_name, long access, devserver *ds_ptr, long *erro
 	try 
 	{
 		Tango::DbDevImportInfo dev_info;
+		string dev_name_str(dev_name);
 
-		dev_info = tango_dbase->import_device(dev_name);
+		dev_info = tango_dbase->import_device(dev_name_str);
 
 //
 // device defined but not exported - case for stateless import
@@ -374,7 +401,7 @@ long tango_dev_import(char *dev_name, long access, devserver *ds_ptr, long *erro
 		tango_device_tmp.cmd_value = vector<long>(cmd_query->length());
 		tango_device_tmp.argin_type = vector<long>(cmd_query->length());
 		tango_device_tmp.argout_type = vector<long>(cmd_query->length());
-		for (long i = 0;i < cmd_query->length();i++)
+		for (i = 0;i < cmd_query->length();i++)
 		{
 			long error;
 			tango_device_tmp.cmd_name[i] = string((*cmd_query)[i].cmd_name);
@@ -391,7 +418,7 @@ long tango_dev_import(char *dev_name, long access, devserver *ds_ptr, long *erro
                 	return(DS_NOTOK);
         	}
 		tango_device_free = -1;
-		for (long i = 0; i < tango_device.size(); i++)
+		for (i = 0; i < tango_device.size(); i++)
 		{
 			if (tango_device[i].flag == TANGO_DEV_FREE)
 			{
@@ -505,8 +532,9 @@ long tango_dev_reimport(devserver ds, long *error)
 	try 
 	{
 		Tango::DbDevImportInfo dev_info;
+		string device_name_str(ds->device_name);
 
-                dev_info = tango_dbase->import_device(ds->device_name);
+                dev_info = tango_dbase->import_device(device_name_str);
 
                 if (dev_info.exported == 0)
                 {
@@ -1291,6 +1319,8 @@ static void tango_any_to_argout(long argout_type, long tango_type, CORBA::Any re
 					             break;
 					case (Tango::FAULT) : *argout_short = DEVFAULT; 
 					             break;
+					case (Tango::INIT) : *argout_short = DEVINIT; 
+					             break;
 					case (Tango::RUNNING) : *argout_short = DEVRUN; 
 					             break;
 					case (Tango::ALARM) : *argout_short = DEVALARM; 
@@ -1688,6 +1718,8 @@ static void tango_any_to_argout_raw(long argout_type, long tango_type, CORBA::An
 					             break;
 					case (Tango::FAULT) : taco_short = DEVFAULT; 
 					             break;
+					case (Tango::INIT) : taco_short = DEVINIT; 
+					             break;
 					case (Tango::RUNNING) : taco_short = DEVRUN; 
 					             break;
 					case (Tango::ALARM) : taco_short = DEVALARM; 
