@@ -13,13 +13,31 @@
  Original:      July 1993
 
 
- $Revision: 4.51 $
- $Date: 2000/03/27 18:05:51 $
+ $Revision: 4.57 $
+ $Date: 2002/06/06 15:35:14 $
 
- $Author: pons $
+ $Author: meyer $
 
  $Log:	CntrlDsNumbers.h,v $
- * Revision 4.51  2000/03/27  18:05:51  18:05:51  pons ()
+ * Revision 4.57  2002/06/06  15:35:14  15:35:14  meyer (J.Meyer)
+ * Added RadSurveyBase
+ * 
+ * Revision 4.56  2002/02/22  13:19:46  13:19:46  meyer (J.Meyer)
+ * Corrected base number.
+ * 
+ * Revision 4.55  2002/02/22  13:14:25  13:14:25  meyer (J.Meyer)
+ * Added stetching cell class.
+ * 
+ * Revision 4.54  2002/01/16  17:41:18  17:41:18  pons ()
+ * Add DevCAV78CoolBase class (CAV78 Coolling)
+ * 
+ * Revision 4.53  2001/05/29  13:06:03  13:06:03  chaize (Jm.Chaize)
+ * *** empty log message ***
+ * 
+ * Revision 4.52  01/02/19  11:38:27  11:38:27  pons ()
+ * Add Transversal feedback Class base
+ * 
+ * Revision 4.51  20/0./3.  7.:8.:5.  7.:8.:5.  pons ()
  * Add the DevIPTaxiBase.
  * 
  * Revision 4.50  2000/02/15  12:48:18  12:48:18  meyer (J.Meyer)
@@ -402,4 +420,13 @@
 #define DevFrontEndLogBase (CntrlTeamNumber + DS_LSHIFT(78, DS_IDENT_SHIFT))
 /* IPTaxi Class base */
 #define DevIPTaxiBase (CntrlTeamNumber + DS_LSHIFT(79, DS_IDENT_SHIFT))
+/* Transversal feedback Class base */
+#define DevFeedTransBase (CntrlTeamNumber + DS_LSHIFT(80, DS_IDENT_SHIFT))
+#define DevHDBBase (CntrlTeamNumber + DS_LSHIFT(81, DS_IDENT_SHIFT))
+/* Cav78 Coolling Class base */
+#define DevCAV78CoolBase (CntrlTeamNumber + DS_LSHIFT(82, DS_IDENT_SHIFT))
+/* Stretching cell Class base */
+#define DevSCBase (CntrlTeamNumber + DS_LSHIFT(83, DS_IDENT_SHIFT))
+/* Radiation Survey Class base */
+#define DevRadSurveyBase (CntrlTeamNumber + DS_LSHIFT(84, DS_IDENT_SHIFT))
 #endif	/* _CntrlDsNumbers_h */
