@@ -14,15 +14,24 @@
  Original:	June 1991
 
 
- $Revision: 4.34 $
- $Date: 2001/03/21 18:44:22 $
+ $Revision: 4.37 $
+ $Date: 2002/05/28 08:43:57 $
 
- $Author: goetz $
+ $Author: beteva $
 
  $Log: DevCmds.h,v $
- Revision 4.34  2001/03/21 18:44:22  goetz
- added DevCmdNameListEntry typedef for dev_cmds.c
+ Revision 4.37  2002/05/28 08:43:57  beteva
+ Added Extended device commnads, removed some Hook commands
 
+ Revision 4.36  2002/03/07 20:52:43  goetz
+ added cmd_name field to CmdListEntry
+
+ Revision 4.35  2001/11/20 16:26:43  beteva
+ added the Hook commands (AB)
+
+ * Revision 4.34  2001/03/21  18:44:22  18:44:22  goetz (Andy Goetz)
+ * added DevCmdNameListEntry typedef for dev_cmds.c
+ * 
  Revision 4.33  2001/01/10 10:20:18  goetz
  added B.Perdersen's patch to query events
 
@@ -134,7 +143,7 @@
  */
 #ifdef _IDENT
 static char DevCmdsh[] = 
-"@(#)$Header: /segfs/dserver/dev/system/api/cmds_err/include/RCS/DevCmds.h,v 4.34 2001/03/21 18:44:22 goetz Exp $";
+"@(#)$Header: /segfs/dserver/system/api/cmds_err/include/RCS/DevCmds.h,v 4.37 2002/05/28 08:43:57 beteva Exp $";
 #endif /* _IDENT */
 
 
@@ -184,6 +193,7 @@ typedef long int (*DevCommandFunction)();
 #define DevReadCommand          30		
 #define DevForce		31
 #define DevUnforce		32
+
 /*
  * commands for power supplies
  */
@@ -796,10 +806,17 @@ typedef long int (*DevCommandFunction)();
 #define DevSetFastDelay		1309
 
 
-/*** New generic command for DS configuration ***/
+/*** More generic commands  ***/
 
-#define DevGetDsConfig		1500
+#define DevGetDsConfig    1500
+#define DevGetDebugFlags  1501
+#define DevSetDebugFlags  1502
+#define DevOpenDynOutput  1503
+#define DevCloseDynOutput 1504
+#define GetDevList        1505
 
+#define DevHookInstall    1510
+#define DevHookRelease    1511
 
 /*
  *  definitions for class command list
@@ -812,6 +829,7 @@ typedef struct _DevCommandListEntry {
 				     DevArgType		argin_type;
 				     DevArgType		argout_type;
 				     long		min_access;
+				     char		*cmd_name;
                                     }
 	       DevCommandListEntry;
 
