@@ -12,11 +12,17 @@
 
  Original:	March 1990
 
- Version:	$Revision: 4.44 $
+ Version:	$Revision: 4.46 $
 
- Date:		$Date: 98/12/22 10:16:29 $
+ Date:		$Date: 2002/03/07 15:30:23 $
+
+ $Log: DevErrors.h,v $
+ Revision 4.46  2002/03/07 15:30:23  goetz
+ added DbErr_NoDatabase
+
+ Revision 4.45  2002/01/09 15:32:54  beteva
+ added DevErr_Reset, DevErr_ConnectionError and DevErr_BusError (Linux drivers handling)
 
- $Log:	DevErrors.h,v $
  * Revision 4.44  98/12/22  10:16:29  10:16:29  taurel (E.Taurel)
  * Added a const for the mesage field of the DevErrListEntry structure.
  * 
@@ -164,7 +170,7 @@
  */
 #ifdef _IDENT
 static char DevErrorsh[] =
-"@(#)$Header: DevErrors.h,v 4.44 98/12/22 10:16:29 taurel Exp $";
+"@(#)$Header: /segfs/dserver/system/api/cmds_err/include/RCS/DevErrors.h,v 4.46 2002/03/07 15:30:23 goetz Exp $";
 #endif /* _IDENT */
 
 /*
@@ -257,6 +263,9 @@ typedef struct { short err_type;
 #define DevErr_CannotForkProcess		64
 #define DevErr_BadChecksum			65
 #define DevErr_DeviceInFaultState               66
+#define DevErr_Reset                            67
+#define DevErr_ConnectionError                  68
+#define DevErr_BusError                         69
 
 #define DevErr_DeviceNoInputAvailable		71
 #define DevErr_DeviceNotInRemote		72
@@ -422,6 +431,7 @@ typedef struct { short err_type;
  *  Number 400-500 database server error messages
  */
 
+#define DbErr_NoDatabase			400
 #define DbErr_CannotCreateClientHandle		401
 #define DbErr_RPCreception                      402
 #define DbErr_DatabaseAccess                    403
