@@ -1,6 +1,24 @@
-static char RcsId[] = "@(#)$Header: dc_serv.c,v 3.19 99/07/05 14:24:23 taurel Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dserver/system/dc/svc/RCS/dc_serv.c,v 3.25 2002/07/05 11:17:05 taurel Rel $";
 
-/* $Log:	dc_serv.c,v $
+/* $Log: dc_serv.c,v $
+ * Revision 3.25  2002/07/05 11:17:05  taurel
+ * DC servers now create their own devices and have default resource values
+ *
+ * Revision 3.24  2002/03/12 11:26:55  goetz
+ * solaris now uses sigset() and not sigvec anymore
+ *
+ * Revision 3.23  1901/02/20 17:47:20  taurel
+ * Add some test on the ptr retrieved from shared memory for the read server (dc_read.c file)
+ *
+ * Revision 3.22  2001/02/19 12:50:14  goetz
+ * checkin for taurel
+ *
+ * Revision 3.21  2000/12/03 07:19:13  goetz
+ * ported to Linux
+ *
+ * Revision 3.20  2000/03/13 15:28:32  taurel
+ * Adapted to the new release of gettranscient (DSAIPI release 7.8 and above)
+ *
  * Revision 3.19  99/07/05  14:24:23  14:24:23  taurel (E.Taurel)
  * Porte dto new release of gettranscienr_ut. I don't understand how it worked
  * before !!
