@@ -1,6 +1,9 @@
-static char RcsId[] = "@(#)$Header: /segfs/dserver/system/dc/svc/RCS/dcwr_svc.c,v 3.24 2002/03/12 11:26:55 goetz Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dserver/system/dc/svc/RCS/dcwr_svc.c,v 3.25 2002/07/05 11:17:05 taurel Rel $";
 
 /* $Log: dcwr_svc.c,v $
+ * Revision 3.25  2002/07/05 11:17:05  taurel
+ * DC servers now create their own devices and have default resource values
+ *
  * Revision 3.24  2002/03/12 11:26:55  goetz
  * solaris now uses sigset() and not sigvec anymore
  *
@@ -288,6 +291,8 @@ char *argv[];
 	(void) sigset(SIGLOST, default_sig);
 #endif /* _solaris */
 #else
+	sigact.sa_flags = 0;
+	sigemptyset(&sigact.sa_mask);
         sigact.sa_handler = SIG_IGN;
         sigaction(SIGHUP, &sigact, NULL);
         sigact.sa_handler = un_register_prog;
@@ -702,7 +707,10 @@ char *c_proc_name;
 	char h_name[40];
 	char proc_name[40];
 	char *ptr;
-
+	char dev_def[256];
+	char **dev_def_array;
+	long dev_def_err;
+	
 /* Get host information */
 
 	if ((host = gethostbyname(host_name)) == NULL)
@@ -780,13 +788,49 @@ char *c_proc_name;
 
 	if (db_dev_export(&devinfo,1,&error))
 	{
-		fprintf(stderr,"dc_server_wr : Can't export me to outside world, exiting...\n");
-		fprintf(stderr,"dc_server_wr : Error code : %d\n",error);
-		return(-1);
+		if (error != DbErr_DeviceNotDefined)
+		{
+			fprintf(stderr,"dc_server_wr : Can't export me to outside world, exiting...\n");
+			fprintf(stderr,"dc_server_wr : Error code : %d\n",error);
+			return(-1);
+		}
+		else
+		{
+		
+/* Build the device definition string */
+
+			strcpy(dev_def,ds_name);
+			strcat(dev_def,"/device:");
+			strcat(dev_def,d_name);
+
+			dev_def_array = calloc(1,sizeof(char *));
+			dev_def_array[0] = dev_def;
+		
+			if (db_upddev(1,dev_def_array,&dev_def_err,&error) == -1)
+			{
+				fprintf(stderr,"dc_server_wr: Pseudo device for dc server not defined in db\n");
+				fprintf(stderr," and I can't defined it. Error = %d\n",error);
+				return(-1);
+			}
+
+/* Export me to the outside world */
+			
+			if (db_dev_export(&devinfo,1,&error) == -1)
+			{
+				fprintf(stderr,"dc_server_wr : Can't export me to outside world, exiting...\n");
+				fprintf(stderr,"dc_server_wr : Error code : %d\n",error);
+				return(-1);
+			}
+		}
 	}
 
-/* Retrieve server resources */
+/* Retrieve server resources. Assign some default value sto these resources in
+   case they are not defined in database */
 
+	req.start_req = 8;
+	req.start_nb = 8;
+	req.update = 256;
+	
 	res_serv_get[0].resource_adr = &req.start_req;
 	res_serv_get[1].resource_adr = &req.start_nb;
 	res_serv_get[2].resource_adr = &req.update;
