@@ -13,14 +13,14 @@
 
 
  $Revision: 4.11 $
- $Date: 20/0./3. 5.:7.:3. $
+ $Date: 2000/03/15 17:23:23 $
 
  $Author: taurel $
 
- $Log:	ManagerP.h,v $
- * Revision 4.11  20/0./3.  5.:7.:3.  5.:7.:3.  taurel (E.Taurel)
- * Remove the chmod for unix operating system
- * 
+ $Log: ManagerP.h,v $
+ Revision 4.11  2000/03/15 17:23:23  taurel
+ Remove the chmod for unix operating system
+
  * Revision 4.10  99/11/21  20:36:15  20:36:15  goetz (Andy Goetz)
  * calling svc_destroy() before execv() for database and message server (M.Diehl patch)
  * 
