@@ -1,5 +1,5 @@
 static char RcsId[] =
-"@(#)$Header: Manager.c,v 4.12 20/0./3. 5.:7.:3. taurel Rel $ ";
+"@(#)$Header: /segfs/dserver/system/manager/src/RCS/Manager.c,v 4.13 2002/09/26 11:05:22 goetz Exp $ ";
 /*********************************************************************
 
  File:          Manager.c
@@ -13,15 +13,18 @@ static char RcsId[] =
  Original:	January 1991
 
 
- $Revision: 4.12 $
- $Date: 20/0./3. 5.:7.:3. $
+ $Revision: 4.13 $
+ $Date: 2002/09/26 11:05:22 $
 
- $Author: taurel $
+ $Author: goetz $
+
+ $Log: Manager.c,v $
+ Revision 4.13  2002/09/26 11:05:22  goetz
+ replaced display with nada
+
+ Revision 4.12  2000/03/15 17:23:21  taurel
+ Remove the chmod for unix operating system
 
- $Log:	Manager.c,v $
- * Revision 4.12  20/0./3.  5.:7.:3.  5.:7.:3.  taurel (E.Taurel)
- * Remove the chmod for unix operating system
- * 
  * Revision 4.11  99/11/21  20:36:15  20:36:15  goetz (Andy Goetz)
  * calling svc_destroy() before execv() for database and message server (M.Diehl patch)
  * 
@@ -153,7 +156,7 @@ _msg_manager_data *rpc_msg_register_1 (register_data)
 	 */
 
 	msg_manager_data.dshome  = dshome;
-	msg_manager_data.display = display;
+	msg_manager_data.display = "nada";
 
 
 	/*
