@@ -1,5 +1,5 @@
 static char RcsId[] =
-"@(#)$Header: DevXdrKernel.c,v 5.21 2001/11/12 10:01:36 goetz Rel $";
+"@(#)$Header: /segfs/dserver/system/xdr/src/RCS/DevXdrKernel.c,v 5.22 2002/03/11 12:35:57 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -15,15 +15,18 @@ static char RcsId[] =
  Original:	November 1993
 
 
- $Revision: 5.21 $
- $Date: 2001/11/12 10:01:36 $
+ $Revision: 5.22 $
+ $Date: 2002/03/11 12:35:57 $
 
  $Author: goetz $
 
- $Log:	DevXdrKernel.c,v $
- * Revision 5.21  2001/11/12  10:01:36  10:01:36  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
- * 
+ $Log: DevXdrKernel.c,v $
+ Revision 5.22  2002/03/11 12:35:57  goetz
+ added extern C prototype to VGC xdr routines for C++
+
+ Revision 5.21  2001/11/12 10:01:36  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 5.20  2001/01/08 12:17:35  goetz
  added patch by B.Pedersen to support querying events
 
